import { NotFoundException } from '@nestjs/common';
import { QueryHandler } from '@nestjs/cqrs';
import { ConfigurationRepository } from '../../adapters/secondaries/configuration.repository';
import { FindConfigurationByUuidQuery } from '../../queries/find-configuration-by-uuid.query';
import { Configuration } from '../entities/configuration';

@QueryHandler(FindConfigurationByUuidQuery)
export class FindConfigurationByUuidUseCase {
  constructor(private readonly _repository: ConfigurationRepository) {}

  async execute(
    findConfigurationByUuid: FindConfigurationByUuidQuery,
  ): Promise<Configuration> {
    try {
      const configuration = await this._repository.findOneByUuid(
        findConfigurationByUuid.uuid,
      );
      if (!configuration) throw new NotFoundException();
      return configuration;
    } catch (error) {
      throw error;
    }
  }
}
